@@ -1,5 +1,5 @@
 /*
- *      $Id: CairoWorkstation.c 15126 2014-03-14 20:41:42Z brownrig $
+ *      $Id: CairoWorkstation.c 15910 2015-01-12 19:03:40Z brownrig $
  */
 
 #include   <stdio.h>
@@ -25,9 +25,6 @@ static NhlResource resourcesDocumentWS[] = {
     {NhlNwkOrientation, NhlCwkOrientation, NhlTWorkOrientation,
         sizeof (NhlWorkOrientation), Oset(orientation), NhlTImmediate,
         _NhlUSET((NhlPointer) NhlPORTRAIT), _NhlRES_DEFAULT, NULL},
-    {NhlNwkPDFResolution, NhlCwkPDFResolution, NhlTInteger,
-        sizeof (int), Oset(dpi), NhlTImmediate,
-        _NhlUSET((NhlPointer) 1800), _NhlRES_NOSACCESS, NULL},
 
     /* these page size and margins are initialized as "-1" here, and are given appropriate
      * values when the workstation is opened, depending upon which resources are actually
@@ -159,6 +156,7 @@ static NhlResource resourcesWindowWS[] = {
         _NhlUSET((NhlPointer) False), _NhlRES_DEFAULT, NULL},
 };
 
+#ifdef BuildQtEnabled
 static NhlResource resourcesQtWS[] = {
     {NhlNwkFormat, NhlCwkFormat, NhlTCairoFormat, sizeof (NhlCairoFormat),
         Oset(format), NhlTImmediate, _NhlUSET((NhlPointer) NhlCQT),
@@ -203,6 +201,7 @@ static NhlResource resourcesQtWS[] = {
         sizeof (NhlBoolean), Oset(cairo_fill_hack), NhlTImmediate,
         _NhlUSET((NhlPointer) False), _NhlRES_DEFAULT, NULL},
 };
+#endif
 
 /* forward declarations of helper functions */
 static NhlErrorTypes fixupFilename(NhlCairoWorkstationLayer layer, char* filenameSuffix, char* callingFunc);
@@ -233,22 +232,29 @@ static NhlErrorTypes CairoImageWorkstationInitialize(NhlClass class, NhlLayer re
         NhlLayer new, _NhlArgList args, int num_args);
 static NhlErrorTypes CairoWindowWorkstationInitialize(NhlClass class, NhlLayer req,
         NhlLayer new, _NhlArgList args, int num_args);
+#ifdef BuildQtEnabled
 static NhlErrorTypes CairoQtWorkstationInitialize(NhlClass class, NhlLayer req,
         NhlLayer new, _NhlArgList args, int num_args);
-
+#endif
 
 static NhlErrorTypes CairoDocumentWorkstationOpen(NhlLayer instance);
 static NhlErrorTypes CairoImageWorkstationOpen(NhlLayer instance);
 static NhlErrorTypes CairoWindowWorkstationOpen(NhlLayer instance);
+#ifdef BuildQtEnabled
 static NhlErrorTypes CairoQtWorkstationOpen(NhlLayer instance);
+#endif
 
 static NhlErrorTypes CairoDocumentWorkstationActivate(NhlLayer instance);
 static NhlErrorTypes CairoImageWorkstationActivate(NhlLayer instance);
 static NhlErrorTypes CairoWindowWorkstationActivate(NhlLayer instance);
+#ifdef BuildQtEnabled
 static NhlErrorTypes CairoQtWorkstationActivate(NhlLayer instance);
+#endif
 
 static NhlErrorTypes CairoWindowWorkstationClear(NhlLayer instance);
+#ifdef BuildQtEnabled
 static NhlErrorTypes CairoQtWorkstationClear(NhlLayer instance);
+#endif
 
 /* class-record for PS/PDF output formats */
 NhlCairoWorkstationClassRec NhlcairoDocumentWorkstationClassRec = {
@@ -445,6 +451,7 @@ NhlCairoWorkstationClassRec NhlcairoWindowWorkstationClassRec = {
 
 };
 
+#ifdef BuildQtEnabled
 /* class-record for qt-based output formats */
 NhlCairoWorkstationClassRec NhlcairoQtWorkstationClassRec = {
     {
@@ -509,11 +516,14 @@ NhlCairoWorkstationClassRec NhlcairoQtWorkstationClassRec = {
     }
 
 };
+#endif
 
 NhlClass NhlcairoDocumentWorkstationClass = (NhlClass) & NhlcairoDocumentWorkstationClassRec;
 NhlClass NhlcairoImageWorkstationClass = (NhlClass) & NhlcairoImageWorkstationClassRec;
 NhlClass NhlcairoWindowWorkstationClass = (NhlClass) & NhlcairoWindowWorkstationClassRec;
+#ifdef BuildQtEnabled
 NhlClass NhlcairoQtWorkstationClass = (NhlClass) & NhlcairoQtWorkstationClassRec;
+#endif
 
 /*
  * Function:    nhlfcairoXXXXXworkstationclass
@@ -541,9 +551,11 @@ NhlClass
 _NHLCALLF(nhlfcairowindowworkstationclass, NHLFCAIROWINDOWWORKSTATIONCLASS)
 (void) { return NhlcairoWindowWorkstationClass; }
 
+#ifdef BuildQtEnabled
 NhlClass
 _NHLCALLF(nhlfcairoqtworkstationclass, NHLFCAIROQTWORKSTATIONCLASS)
 (void) { return NhlcairoQtWorkstationClass; }
+#endif
 
 /*
  * Function:    CairoWorkstationClassPartInitialize
@@ -621,8 +633,10 @@ CairoWorkstationClassInitialize(void) {
                 imageFormats, NhlNumber(imageFormats));
         (void) _NhlRegisterEnumType(NhlcairoWindowWorkstationClass, NhlTCairoFormat,
                 windowFormats, NhlNumber(windowFormats));
+#ifdef BuildQtEnabled
         (void) _NhlRegisterEnumType(NhlcairoQtWorkstationClass, NhlTCairoFormat,
                 qtFormats, NhlNumber(qtFormats));
+#endif
 
         (void) _NhlRegisterEnumType(NhlcairoDocumentWorkstationClass, NhlTWorkOrientation,
                 orientvals, NhlNumber(orientvals));
@@ -825,6 +839,7 @@ CairoWindowWorkstationInitialize(NhlClass lclass, NhlLayer req, NhlLayer new, _N
     return ret;
 }
 
+#ifdef BuildQtEnabled
 static NhlErrorTypes
 CairoQtWorkstationInitialize(NhlClass lclass, NhlLayer req, NhlLayer new, _NhlArgList args, int num_args) {
     char func[] = "CairoQtWorkstationInitialize";
@@ -892,7 +907,7 @@ CairoQtWorkstationInitialize(NhlClass lclass, NhlLayer req, NhlLayer new, _NhlAr
 
     return ret;
 }
-
+#endif
 
 /*
  * Function:    CairoWorkstationSetValues
@@ -1087,7 +1102,6 @@ CairoDocumentWorkstationOpen(NhlLayer l) {
     c_ngsetc("me", cairo->filename);
     c_ngseti("pw", pageInfo.pageWidthPts);
     c_ngseti("ph", pageInfo.pageHeightPts);
-    c_ngseti("co", (cairo->dpi / 72 + 1));
     c_ngseti("lx", cairo->lower_x);
     c_ngseti("ux", cairo->upper_x);
     c_ngseti("ly", cairo->lower_y);
@@ -1102,7 +1116,6 @@ CairoDocumentWorkstationOpen(NhlLayer l) {
     w = cairo->upper_x - cairo->lower_x;
     h = cairo->upper_y - cairo->lower_y;
     d = MAX(w, h);
-    work->work.vswidth_dev_units = d / 72 * cairo->dpi;
     
     setCairoFillHackValue(l);
 
@@ -1111,6 +1124,7 @@ CairoDocumentWorkstationOpen(NhlLayer l) {
 
 static NhlErrorTypes
 CairoImageWorkstationOpen(NhlLayer l) {
+    NhlWorkstationLayer work = (NhlWorkstationLayer) l;
     NhlCairoWorkstationLayerPart *cairo = &((NhlCairoWorkstationLayer) l)->cairo;
     Gescape_in_data gesc_in_pixconf;
     NhlErrorTypes ret;
@@ -1145,29 +1159,10 @@ CairoImageWorkstationOpen(NhlLayer l) {
 static NhlErrorTypes
 CairoWindowWorkstationOpen(NhlLayer l) {
     char func[] = "XWorkstationOpen";
+    NhlWorkstationLayer work = (NhlWorkstationLayer) l;
     NhlCairoWorkstationLayerPart *cairo = &((NhlCairoWorkstationLayer) l)->cairo;
     Gescape_in_data gesc_in_xwconf;
     NhlErrorTypes ret;
-    /*****
-            NhlXWorkstationLayer		xl = (NhlXWorkstationLayer)l;
-            NhlXWorkstationLayerPart	*xp = &xl->xwork;
-            NhlWorkstationClassPart	*wcp =
-                    &((NhlWorkstationClass)xl->base.layer_class)->work_class;
-            _NGCXGetSizeChg			xgsc;
-            Gescape_in_data			gesc_in_xgsc;
-            Gescape_in_data			gesc_in_xwconf;
-
-            if(xl->work.gkswkstype == NhlFATAL) {
-                    NhlPError(NhlFATAL,NhlEUNKNOWN,"Unknown workstation type");
-                    return(NhlFATAL);
-
-            }
-            if(xl->work.gkswksconid == NhlFATAL) {
-                    NhlPError(NhlFATAL,NhlEUNKNOWN,
-                            "Unknown workstation connection id");
-                    return(NhlFATAL);
-            }
-     *****/
 
     /* we need to calculate the NDC frame within the image... */
     int minRange = (cairo->xwinconfig.width < cairo->xwinconfig.height) ? cairo->xwinconfig.width : cairo->xwinconfig.height;
@@ -1193,33 +1188,13 @@ CairoWindowWorkstationOpen(NhlLayer l) {
     ret = (*NhlworkstationClassRec.work_class.open_work)(l);
 
     return ret;
-    /****
-    _NhlUpdateGksWksRecs(l,True,&xl->work.gkswksid);
-     *wcp->hlu_wks_flag = True;
-    _NHLCALLF(gopwk,GOPWK)(&(xl->work.gkswksid),&(xl->work.gkswksconid),
-            &(xl->work.gkswkstype));
-    if(_NhlLLErrCheckPrnt(NhlFATAL,func))
-            return NhlFATAL;
-    gset_clip_ind(GIND_NO_CLIP);
-    if(_NhlLLErrCheckPrnt(NhlWARNING,func)){
-            return NhlFATAL;
-    }
-    gesc_in_xgsc.escape_r1.data = &xgsc;
-    gesc_in_xgsc.escape_r1.size = 0;
-    xgsc.type = NGC_XSIZECHG;
-    xgsc.work_id = xl->work.gkswksid;
-    xgsc.xget_size = GetSizeProc;
-    xgsc.closure = &xl->work.vswidth_dev_units;
-    gescape(NGESC_CNATIVE,&gesc_in_xgsc,NULL,NULL);
-
-    return _NhlAllocateColors((NhlWorkstationLayer)l);
-
-*****/
 }
 
+#ifdef BuildQtEnabled
 static NhlErrorTypes
 CairoQtWorkstationOpen(NhlLayer l) {
     char func[] = "QtWorkstationOpen";
+    NhlWorkstationLayer work = (NhlWorkstationLayer) l;
     NhlCairoWorkstationLayerPart *cairo = &((NhlCairoWorkstationLayer) l)->cairo;
     Gescape_in_data gesc_in_xwconf;
     NhlErrorTypes ret;
@@ -1249,6 +1224,7 @@ CairoQtWorkstationOpen(NhlLayer l) {
 
     return ret;
 }
+#endif
 
 /*
  * Function:    CairoXXXXXWorkstationActivate
@@ -1285,7 +1261,6 @@ CairoDocumentWorkstationActivate(NhlLayer l) {
     w = pp->upper_x - pp->lower_x;
     h = pp->upper_y - pp->lower_y;
     d = MAX(w, h);
-    wp->vswidth_dev_units = d / 72 * pp->dpi;
 
     return (*(lc->work_class.activate_work))(l);
 }
@@ -1302,11 +1277,13 @@ CairoWindowWorkstationActivate(NhlLayer l) {
     return (*(lc->work_class.activate_work))(l);
 }
 
+#ifdef BuildQtEnabled
 static NhlErrorTypes
 CairoQtWorkstationActivate(NhlLayer l) {
     NhlWorkstationClass lc = (NhlWorkstationClass) NhlworkstationClass;
     return (*(lc->work_class.activate_work))(l);
 }
+#endif
 
 /*
  * Function:	CairoWindowWorkstationClear
@@ -1333,12 +1310,14 @@ CairoWindowWorkstationClear(NhlLayer layer) {
     return (*(wksClass->work_class.clear_work))(layer);
 }
 
+#ifdef BuildQtEnabled
 static NhlErrorTypes
 CairoQtWorkstationClear(NhlLayer layer) {
     NhlWorkstationClass wksClass = (NhlWorkstationClass) NhlworkstationClass;
 
     return (*(wksClass->work_class.clear_work))(layer);
 }
+#endif
 
 /*
  * fixupFilename()
