@@ -856,6 +856,7 @@ static NhlErrorTypes UpdateFillInfo
 	float *levels = (float *) cnp->levels->data;
 	int i;
 
+	*almost_const = False;
         _NhlSetFillOpacity(cl, cnp->fill_opacity);
 /*
  * Since the missing value fill resources are not supposed to be affected
@@ -871,7 +872,6 @@ static NhlErrorTypes UpdateFillInfo
 
 	*do_fill = True;
 
-	*almost_const = False;
 	for (i = 0; i< cnp->level_count -1 ; i++) { 
 		if (cnp->zmin >= levels[i] &&
 		    cnp->zmax <= levels[i + 1]) {
@@ -1610,14 +1610,12 @@ static NhlErrorTypes CnStdRender
 				if (cnp->fill_mode == NhlRASTERFILL) {
 					mode = "RasterFill";
 				}
-				e_text =  "%s: coordinates are out of range for drawing over a map: standard %s rendering method will not work;\n consider setting the resource trGridType to \"TriangularMesh\" if coordinates contain missing values";
-				NhlPError(NhlFATAL,NhlEUNKNOWN,e_text,entry_name,cnp->fill_mode == NhlAREAFILL ? "AreaFill" : "RasterFill");
-				return(NhlFATAL);
+				e_text =  "%s: out of range coordinates encountered; standard %s rendering method may be unreliable;\n consider setting the resource trGridType to \"TriangularMesh\" if coordinates contain missing values";
+				NhlPError(NhlWARNING,NhlEUNKNOWN,e_text,entry_name,cnp->fill_mode == NhlAREAFILL ? "AreaFill" : "RasterFill");
 			}
 			else if (cnp->lines_on || cnp->line_lbls.on) {
-				e_text =  "%s: coordinates are out of range for drawing over a map: standard line or line label rendering method will not work;\n consider setting the resource trGridType to \"TriangularMesh\" if coordinates contain missing values";
-				NhlPError(NhlFATAL,NhlEUNKNOWN,e_text,entry_name);
-				return(NhlFATAL);
+				e_text =  "%s: out of range coordinates encountered; standard line rendering method may be unreliable;\n consider setting the resource trGridType to \"TriangularMesh\" if coordinates contain missing values";
+				NhlPError(NhlWARNING,NhlEUNKNOWN,e_text,entry_name);
 			}
 		}
 	}
@@ -1699,6 +1697,15 @@ static NhlErrorTypes CnStdRender
 		return(ret);
 	}
 	/* Draw the contours */
+#if 0
+	{ /* for debugging */
+		float flx,frx,fby,fuy,wlx,wrx,wby,wuy; int ll;
+		c_getset(&flx,&frx,&fby,&fuy,&wlx,&wrx,&wby,&wuy,&ll);
+		printf("getset - %f,%f,%f,%f,%f,%f,%f,%f\n",
+		       flx,frx,fby,fuy,wlx,wrx,wby,wuy); 
+		/*c_set(flx,frx,fby,fuy,wlx,wrx,wuy,wby,ll);*/
+  	}
+#endif
 
 	subret = _NhlCprect(cnp->data,cnp->sfp->fast_dim,cnp->sfp->fast_len,
 			    cnp->sfp->slow_len,cnp->fws,cnp->iws,entry_name);
@@ -1935,7 +1942,8 @@ static NhlErrorTypes CnStdRender
 		}
 	}
 	
-	if (cnp->do_labels && cnp->label_order == order) {
+	if (cnp->do_labels && cnp->label_order == order &&
+		cnp->llabel_placement != NhlCONSTANT) {
 #if 0
 		subret = SetTransBoundsState
 			(cnl,False,&csrp->do_bounds);
