@@ -1,5 +1,5 @@
 /*
- *      $Id: AddBuiltIns.c 14343 2013-06-19 23:04:39Z huangwei $
+ *      $Id: AddBuiltIns.c 16014 2015-03-02 17:29:52Z huangwei $
  */
 /************************************************************************
 *                                                                       *
@@ -80,6 +80,8 @@ void
 # endif /* NhlNeedProto */
 );
 
+extern NhlErrorTypes _NclIFileExists(void);
+
 extern int _MachineIsBigEndian();
 
 extern NhlErrorTypes _NclIGetFileChunkSizes(void);
@@ -99,7 +101,6 @@ void
 # endif /* NhlNeedProto */
 );
 
-
 extern NhlErrorTypes _NclIprintFileVarSummary(
 #if NhlNeedProto
 void
@@ -955,6 +956,8 @@ void
 #endif
 );
 
+extern NhlErrorTypes _NclIGetFileVarChunkDimsizes(void);
+
 extern NhlErrorTypes _NclIFileVarDimsizes(
 #if     NhlNeedProto
 void
@@ -971,6 +974,9 @@ extern NhlErrorTypes _NclIGetFileVarAtts(
 void
 #endif
 );
+
+extern NhlErrorTypes _NclIGetFileCompoundVarComponentNames(void);
+
 extern NhlErrorTypes _NclIGetVarDims(
 #if     NhlNeedProto
 void
@@ -1024,6 +1030,8 @@ extern NhlErrorTypes _NclIListIndex(
 void
 #endif
 );
+extern NhlErrorTypes _NclIListIndexFromName(void);
+extern NhlErrorTypes _NclIListVarNameFromIndex(void);
 
 extern NhlErrorTypes _NclINhlGetErrorObjectId(
 #if NhlNeedProto
@@ -1075,6 +1083,8 @@ void
 #endif
 );
 
+NhlErrorTypes _NclIgetfilepath(void);
+
 void _NclAddBuiltIns
 #if     NhlNeedProto
 (void)
@@ -2276,6 +2286,14 @@ void _NclAddBuiltIns
 	SetArgTemplate(args,1,"string",1,dimsizes);nargs++;
 	NclRegisterFunc(_NclIGetFileVarAtts,args,"getfilevaratts",nargs);
 
+	nargs = 0;
+	args = NewArgs(2);
+	dimsizes[0] = 1;
+	SetArgTemplate(args,0,"file",0,NclANY);nargs++;
+	SetArgTemplate(args,1,"string",1,dimsizes);nargs++;
+	NclRegisterFunc(_NclIGetFileCompoundVarComponentNames,args,
+			"getfilecompoundvarcomponentnames",nargs);
+
 	nargs = 0;
 	args = NewArgs(1);
 	dimsizes[0] = 1;
@@ -2313,6 +2331,13 @@ void _NclAddBuiltIns
 	SetArgTemplate(args,1,"string",1,dimsizes);nargs++;
 	NclRegisterFunc(_NclIGetFileVarDims,args,"getfilevardims",nargs);
 
+	nargs = 0;
+	args = NewArgs(2);
+	dimsizes[0] = 1;
+	SetArgTemplate(args,0,"file",0,NclANY);nargs++;
+	SetArgTemplate(args,1,"string",1,dimsizes);nargs++;
+	NclRegisterFunc(_NclIGetFileVarChunkDimsizes,args,"getfilevarchunkdimsizes",nargs);
+
 	nargs = 0;
 	args = NewArgs(2);
 	dimsizes[0] = 1;
@@ -2531,6 +2556,20 @@ void _NclAddBuiltIns
     SetArgTemplate(args,nargs,NclANY,1,NclANY);nargs++;
     NclRegisterFunc(_NclIListIndex,args,"ListIndex",nargs);
 
+    nargs = 0;
+    args = NewArgs(2);
+    dimsizes[0] = 1;
+    SetArgTemplate(args,nargs,"list",1,dimsizes);nargs++;
+    SetArgTemplate(args,nargs,"string",1,dimsizes);nargs++;
+    NclRegisterFunc(_NclIListIndexFromName,args,"ListIndexFromName",nargs);
+
+    nargs = 0;
+    args = NewArgs(2);
+    dimsizes[0] = 1;
+    SetArgTemplate(args,nargs,"list",1,dimsizes);nargs++;
+    SetArgTemplate(args,nargs,"integer",1,dimsizes);nargs++;
+    NclRegisterFunc(_NclIListVarNameFromIndex,args,"ListVarNameFromIndex",nargs);
+
     nargs = 0;
     args = NewArgs(1);
     dimsizes[0] = 1;
@@ -2549,7 +2588,6 @@ void _NclAddBuiltIns
     SetArgTemplate(args,nargs,"string",1,dimsizes); nargs++;
     NclRegisterProc(_NclIprintFileVarSummary,args,"printFileVarSummary",nargs);
 
-
     nargs = 0;
     args = NewArgs(3);
     dimsizes[0] = 1;
@@ -2599,6 +2637,11 @@ void _NclAddBuiltIns
     SetArgTemplate(args, nargs, "string", 0, NclANY);  nargs++;
     NclRegisterFunc( _NclIFileIsPresent, args, "isfilepresent", nargs);
 
+    nargs = 0;
+    args = NewArgs(1);
+    SetArgTemplate(args, nargs, "string", 0, NclANY);  nargs++;
+    NclRegisterFunc( _NclIFileExists, args, "fileexists", nargs);
+
     nargs = 0;
     args = NewArgs(1);
     SetArgTemplate(args,nargs,"short",0,NclANY); nargs++;
@@ -2637,6 +2680,11 @@ void _NclAddBuiltIns
     SetArgTemplate(args, nargs, "string", 1, dimsizes);  nargs++;
     NclRegisterFunc(_Ncldefault_fillvalue, args, "default_fillvalue", nargs);
 
+    nargs = 0;
+    args = NewArgs(1);
+    SetArgTemplate(args,nargs,"file",0,NclANY); nargs++;
+    NclRegisterFunc(_NclIgetfilepath,args,"getfilepath",nargs);
+
     nargs = 0;
     args = NewArgs(2);
     dimsizes[0] = 1;
