@@ -1,5 +1,5 @@
 /*
- *      $Id: DataSupport.c 14537 2013-09-04 21:52:44Z huangwei $
+ *      $Id: DataSupport.c 16049 2015-03-06 18:48:20Z huangwei $
  */
 /************************************************************************
 *									*
@@ -840,6 +840,14 @@ NclBasicDataTypes data_type;
 			return(sizeof(int));	
 		case NCL_list:
 			return(sizeof(int));	
+		case NCL_opaque:
+			return(sizeof(char));
+		case NCL_enum:
+			return(sizeof(int));
+		case NCL_vlen:
+			return(sizeof(int));
+		case NCL_reference:
+			return(sizeof(NclQuark));	
 		default:
 			return(-1);
 	}
@@ -1910,13 +1918,72 @@ NclBasicDataTypes totype;
 			return(0);
 		}
 	case NCL_string:
+		{
+		char *val = NrmQuarkToString(*(NrmQuark*)from);
+		char *end;
+
 		switch(totype) {
+		case NCL_byte:
+			*(byte*)to = (byte) _Nclstrtol(val, &end);
+			return(1);
+		case NCL_char:
+			*(char*)to = (char) _Nclstrtoul(val, &end);
+			return(1);
+		case NCL_short:
+			*(short*)to = (short) _Nclstrtol(val, &end);
+			return(1);
+                case NCL_int:
+			*(int*)to = (int) _Nclstrtol(val, &end);
+			return(1);
+		case NCL_long:
+			*(long*)to = _Nclstrtol(val, &end);
+			return(1);
+		case NCL_int64:
+			*(long long*)to = _Nclstrtoll(val, &end);
+			return(1);
+                case NCL_ubyte:
+                        *(unsigned char*)to = (unsigned char) _Nclstrtoul(val, &end);
+                        return(1);
+                case NCL_ushort:
+			*(unsigned short*)to = (unsigned short) _Nclstrtoul(val, &end);
+                        return(1);
+                case NCL_uint:
+			*(unsigned int*)to = (unsigned int) _Nclstrtoul(val, &end);
+                        return(1);
+                case NCL_ulong:
+			*(unsigned long*)to = (unsigned long) _Nclstrtoul(val, &end);
+                        return(1);
+                case NCL_uint64:
+			*(unsigned long long*)to = (unsigned long long) _Nclstrtoull(val, &end);
+                        return(1);
+                case NCL_float:
+			{
+			double dval = strtod(val,&end);
+                	if (end == val || errno == ERANGE) {
+                        	*(float*)to = ((NclTypeClass)nclTypefloatClass)->type_class.default_mis.floatval;
+                	} else
+                        	*(float*)to = (float)dval;
+			return(1);
+			}
+                case NCL_double:
+			{
+			double dval = strtod(val,&end);
+                	if (end == val || errno == ERANGE) {
+                        	*(double*)to = ((NclTypeClass)nclTypedoubleClass)->type_class.default_mis.doubleval;
+                	} else
+                        	*(double*)to = dval;
+			return(1);
+			}
+                case NCL_logical:
+			*(logical*)to = (logical)_Nclstrtol(val, &end);
+			return(1);
 		case NCL_string:
-			*(NclQuark*)to = *(NclQuark*)from;
+			*(NclQuark*)to = (NclQuark*)from;
 			return(1);
 		default:
 			return(0);
 		}
+		}
 	case NCL_logical:
 	default:
 		return(0);
@@ -2549,7 +2616,7 @@ NclBasicDataTypes dt;
 #endif
 {
 	static int first = 1;
-	static NclQuark quarks[25];
+	static NclQuark quarks[26];
 
 	if(first) {
 		first = 0;
@@ -2577,7 +2644,8 @@ NclBasicDataTypes dt;
                 quarks[21] = NrmStringToQuark("opaque");
                 quarks[22] = NrmStringToQuark("enum");
                 quarks[23] = NrmStringToQuark("vlen");
-                quarks[24] = NrmStringToQuark("none");
+                quarks[24] = NrmStringToQuark("reference");
+                quarks[25] = NrmStringToQuark("none");
 	}	
 
 	switch(dt) {
@@ -2625,17 +2693,19 @@ NclBasicDataTypes dt;
 		return(NrmQuarkToString(quarks[22]));
 	case NCL_vlen:
 		return(NrmQuarkToString(quarks[23]));
+	case NCL_reference:
+		return(NrmQuarkToString(quarks[24]));
 	case NCL_none:
         default:
-		return(NrmQuarkToString(quarks[24]));
+		return(NrmQuarkToString(quarks[25]));
 	}
 }
 
 NclBasicDataTypes _nameToNclBasicDataType(NclQuark name)
 {
 	static int first = 1;
-	static NclQuark quarks[24];
-	static NclBasicDataTypes nbd_type[24];
+	static NclQuark quarks[26];
+	static NclBasicDataTypes nbd_type[26];
 	int n;
 
 	if(first) {
@@ -2663,7 +2733,9 @@ NclBasicDataTypes _nameToNclBasicDataType(NclQuark name)
                 quarks[20] = NrmStringToQuark("ubyte");
                 quarks[21] = NrmStringToQuark("opaque");
                 quarks[22] = NrmStringToQuark("enum");
-                quarks[23] = NrmStringToQuark("none");
+                quarks[23] = NrmStringToQuark("vlen");
+                quarks[24] = NrmStringToQuark("reference");
+                quarks[25] = NrmStringToQuark("none");
 
 		nbd_type[0] = NCL_double;
 		nbd_type[1] = NCL_float;
@@ -2688,10 +2760,12 @@ NclBasicDataTypes _nameToNclBasicDataType(NclQuark name)
 		nbd_type[20] = NCL_ubyte;
 		nbd_type[21] = NCL_opaque;
 		nbd_type[22] = NCL_enum;
-		nbd_type[23] = NCL_none;
+		nbd_type[23] = NCL_vlen;
+		nbd_type[24] = NCL_reference;
+		nbd_type[25] = NCL_none;
 	}	
 
-	for(n = 0; n < 24; n++)
+	for(n = 0; n < 26; n++)
 	{
 		if(name == quarks[n])
 			return (nbd_type[n]);
@@ -2952,3 +3026,79 @@ int  type_size;
 	}
 		
 }
+
+long _Nclstrtol(const char *str, char **endptr)
+{
+
+	long tval;
+	int i = 0;
+
+	while (isspace(str[i]))
+			i++;
+	if (strlen(&(str[i])) >= 2 && str[i] == '0' && (str[i+1] == 'x' || str[i+1] == 'X'))
+		tval = strtol(str,endptr,16);
+	else
+		tval = strtol(str,endptr,10);
+	return tval;
+}
+
+unsigned long _Nclstrtoul(const char *str, char **endptr)
+{
+        unsigned long tval;
+        int i = 0;
+
+        while (isspace(str[i]))
+                        i++;
+        if (strlen(&(str[i])) >= 2 && str[i] == '0' && (str[i+1] == 'x' || str[i+1] == 'X'))
+        {
+                tval = strtoul(str,endptr,16);
+        }
+        else
+        {
+                tval = strtoul(str,endptr,10);
+        }
+
+        return tval;
+}
+
+long long _Nclstrtoll(const char *str, char **endptr)
+{
+        long long tval;
+        int i = 0;
+
+        errno = ERANGE;
+
+        while (isspace(str[i]))
+                        i++;
+        if (strlen(&(str[i])) >= 2 && str[i] == '0' && (str[i+1] == 'x' || str[i+1] == 'X'))
+        {
+                errno = 0;
+                tval = local_strtoll(str,endptr,16);
+        }
+        else
+        {
+                errno = 0;
+                tval = local_strtoll(str,endptr,10);
+        }
+
+        return tval;
+}
+
+unsigned long long _Nclstrtoull(const char *str, char **endptr)
+{
+        unsigned long long tval;
+        int i = 0;
+
+        while (isspace(str[i]))
+                        i++;
+        if (strlen(&(str[i])) >= 2 && str[i] == '0' && (str[i+1] == 'x' || str[i+1] == 'X'))
+        {
+                tval = strtoull(str,endptr,16);
+        }
+        else
+        {
+                tval = strtoull(str,endptr,10);
+        }
+
+        return tval;
+}
