@@ -10,6 +10,7 @@ GribTable centers[] = {
 	{8, "US National Weather Service - NWSTG (WMC)"},
 	{9, "US National Weather Service - Other (WMC)"},
 	{10, "Cairo (RSMC/RAFC)"},
+	{11, "Cairo (RSMC/RAFC)"},
 	{12, "Dakar (RSMC/RAFC)"},
 	{13, "Dakar (RSMC/RAFC)"},
 	{14, "Nairobi (RSMC/RAFC)"},
@@ -134,7 +135,7 @@ GribTable centers[] = {
 	{133, "Turkmenistan (NMC)"},
 	{134, "United Arab Emirates (NMC)"},
 	{135, "Uzbekistan (NMC)"},
-	{136, "Socialist Republic of Viet Nam (NMC)"},
+	{136, "Viet Nam (NMC)"},
 	{140, "Bolivia (NMC)"},
 	{141, "Guyana (NMC)"},
 	{142, "Paraguay (NMC)"},
@@ -142,6 +143,7 @@ GribTable centers[] = {
 	{144, "Uruguay (NMC)"},
 	{145, "French Guyana"},
 	{146, "Brazilian Navy Hydrographic Center"},
+	{147, "National Commission on Space Activities - Argentina"},
 	{150, "Antigua and Barbuda (NMC)"},
 	{151, "Bahamas (NMC)"},
 	{152, "Barbados (NMC)"},
@@ -164,7 +166,10 @@ GribTable centers[] = {
 	{169, "Panama (NMC)"},
 	{170, "Saint Lucia (NMC)"},
 	{171, "Trinidad and Tobago (NMC)"},
-	{172, "French Departments"},
+	{172, "French Departments in RA IV"},
+	{173, "US National Aeronautics and Space Administration (NASA)"},
+	{174, "Integrated System Data Management/Marine Environmental Data Service (ISDM/MEDS) - Canada"},
+	{176, "US Cooperative Institude for Meteorological Satellite Studies"},
 	{190, "Cook Islands (NMC)"},
 	{191, "French Polynesia (NMC)"},
 	{192, "Tonga (NMC)"},
@@ -179,6 +184,7 @@ GribTable centers[] = {
 	{201, "Philippines (NMC)"},
 	{202, "Samoa (NMC)"},
 	{203, "Solomon Islands (NMC)"},
+	{204, "Narional Institude of Water and Atmospheric Research - New Zealand"},
 	{210, "Frascati"},
 	{211, "Lanion"},
 	{212, "Lisboa"},
@@ -216,6 +222,8 @@ GribTable centers[] = {
 	{244, "The former Yugoslav Republic of Macedonia (NMC)"},
 	{245, "Ukraine (NMC)"},
 	{246, "Republic of Moldova"},
+	{247, "Operational Programme for the Exchange of Weather RAdar Information (OPERA) - EUMETNET"},
+	{250, "COnsortium for Small scale MOdelling (COSMO)"},
 	{254, "EUMETSAT Operations Center"},
 	{255, "Missing Value"}
 };
@@ -241,7 +249,7 @@ GribTable sub_centers[] = {
         {13, "Federal Aviation Administration"},
         {14, "NWS Meteorological Development Laboratory (MDL)"},
         {15, "The North American Regional Reanalysis (NARR) Project"},
-	{16, "Space Weather Prediciont Center"},
+	{16, "Space Weather Prediction Center"},
 	{150, "ABRFC - Arkansas-Red River RFC, Tulsa OK"},
 	{151, "Alaska RFC, Anchorage, AK"}, 
 	{152, "CBRFC - Colorado Basin RFC, Salt Lake City, UT"},
@@ -261,73 +269,90 @@ GribTable sub_centers[] = {
 
 /* Table A */
 GribTable models[] = {
-	{2, "Ultra Violet Index Model"},
-	{3, "NCEP/ARL Transport and Dispersion Model"},
-	{4, "NCEP/ARL Smoke Model"},
-	{5, "Satellite Derived Precipitation and temperatures, from IR"},
+	{02, "Ultra Violet Index Model"},
+	{03, "NCEP/ARL Transport and Dispersion Model"},
+	{04, "NCEP/ARL Smoke Model"},
+	{05, "Satellite Derived Precipitation and temperatures, from IR"},
+	{06, "NCEP/ARL Dust Model"},
 	{10, "Global Wind-Wave Forecast Model"},
+	{11, "Global Multi-Grid Wave Model (Static Grids)"},
+	{12, "Probabilistic Storm Surge"},
+	{13, "Hurricane Multi-Grid Wave Model"},
+	{14, "Extratropical Storm Surge Model"},
+	{15, "Nearshore Wave Prediction System (NWPS)"},
 	{19, "Limited-area Fine Mesh (LFM) analysis"},
 	{25, "Snow Cover Analysis"},
 	{30, "Forecaster generated field"},
+        {39, "Nested Grid Forecast Model (NGM)"},
 	{31, "Value added post processed field"},
-	{39, "Nested Grid forecast Model (NGM)"},
-	{42, "Global Optimum Interpolation Analysis (GOI) from \"Aviation\" run"},
+	{42, "Global Optimum Interpolation Analysis (GOI) from GFS model"},
 	{43, "Global Optimum Interpolation Analysis (GOI) from \"Final\" run"},
 	{44, "Sea Surface Temperature Analysis"},
 	{45, "Coastal Ocean Circulation Model"},
 	{46, "HYCOM - Global"},
-	{47, "HYCOM - North Pacific Basin"},
-	{48, "HYCOM - North Atlantic Basin"},
+	{47, "HYCOM - North Pacific basin"},
+	{48, "HYCOM - North Atlantic basin"},
 	{49, "Ozone Analysis from TIROS Observations"},
 	{52, "Ozone Analysis from Nimbus 7 Observations"},
 	{53, "LFM-Fourth Order Forecast Model"},
 	{64, "Regional Optimum Interpolation Analysis (ROI)"},
-	{68, "80 wave triangular, 18-layer Spectral model from \"Aviation\" run"},
+	{68, "80 wave triangular, 18-layer Spectral model from GFS model"},
 	{69, "80 wave triangular, 18 layer Spectral model from \"Medium Range Forecast\" run"},
 	{70, "Quasi-Lagrangian Hurricane Model (QLM)"},
 	{73, "Fog Forecast model - Ocean Prod. Center"},
 	{74, "Gulf of Mexico Wind/Wave"},
 	{75, "Gulf of Alaska Wind/Wave"},
 	{76, "Bias corrected Medium Range Forecast"},
-	{77, "126 wave triangular, 28 layer Spectral model from \"Aviation\" run"},
+	{77, "126 wave triangular, 28 layer Spectral model from GFS model"},
+	{78, "126 wave triangular, 28 layer Spectral model from \"Medium Range Forecast\" run"},
 	{79, "Backup from the previous run"},
 	{80, "62 wave triangular, 28 layer Spectral model from \"Medium Range Forecast\" run"},
-	{81, "Spectral Statistical Interpolation (SSI) analysis from \"Aviation\" run."},
-	{82, "Spectral Statistical Interpolation (SSI) analysis from \"Final\" run."},
-	{83, "ETA Model - 80 km version"},
-	{84, "MESO ETA Model"},
-	{85, "ETA Model - 30 km version"},
-	{86, "RUC Model, from Forecast Systems Lab (isentropic; scale: 60km at 40N)"},
+	{81, "Analysis from GFS (Global Forecast System)"},
+	{82, "Analysis from GDAS (Global Data Assimilation System)"},
+	{83, "High Resolution Rapid Refresh (HRRR)"},
+	{84, "MESO NAM Model (currently 12 km)"},
+	{85, "Real Time Ocean Forecast System (RTOFS)"},
+	{86, "RUC Model, from Forecast Systems Lab (isentropic; scale 60km at 40N)"},
 	{87, "CAC Ensemble Forecasts from Spectral (ENSMB)"},
 	{88, "NOAA Wave Watch III (NWW3) Ocean Wave Model"},
+	{89, "Non-hydrostatic Meso Model (NMM) (Currently 8 km)"},
+	{90, "62 wave triangular, 28 layer spectral model extension of the \"Medium Range Forecast\" run"},
+	{91, "62 wave triangular, 28 layer spectral model extension of the GFS model"},
 	{92, "62 wave triangular, 28 layer spectral model run from the \"Medium Range Forecast\" final analysis"},
+	{93, "62 wave triangular, 28 layer spectral model run from the T62 GDAS analysis of the \"Medium Range Forecast\" run"},
 	{94, "T170/L42 Global Spectral Model from MRF run"},
 	{95, "T126/L42 Global Spectral Model from MRF run"},
-	{96, "Global Forecast System Model (formerly known as the Aviation), T382 - Forecast hours 00-180, T190 - Forecast hours 192-384"},
+	{96, "Global Forecast System Model (T1534 - Forecast hours 00-384, T574 - Forecast hours 00-192, T190 - Forecast hours 204-384)"},
+	{98, "Climate Forecast System Model -- Atmospheric model (GFS) coupled to a multi level ocean model (Currently GFS spectral model at T62, 64 levels coupled to 40 level MOM3 ocean model)"},
 	{99, "Miscellaneous Test ID"},
-	{100, "RUC Surface Analysis (scale: 60km at 40N)"},
-	{101, "RUC Surface Analysis (scale: 40km at 40N)"},
-	{105, "RUC Model from FSL (isentropic; scale: 20km at 40N)"},
+        {100, "RUC Surface Analysis (scale: 60km at 40N)"},
+        {101, "RUC Surface Analysis (scale: 40km at 40N)"},
+	{105, "Rapid Refresh (RAP)"},
+	{107, "Global Ensemble Forecast System (GEFS)"},
 	{108, "LAMP"},
 	{109, "RTMA (Real Time Mesoscale Analysis)"},
 	{110, "NAM Model - 15km version"},
-	{111, "Eta model, generic resolution (Used in SREF processing)"},
+	{111, "NAM model, generic resolution (Used in SREF processing)"},
 	{112, "WRF-NMM model, generic resolution (Used in various runs) NMM=Nondydrostatic Mesoscale Model (NCEP)"},
-        {113, "Products from NCEP SREF processing"},
-        {115, "Downscaled GFS from Eta eXtension"},
-        {116, "WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)"},
+	{113, "Products from NCEP SREF processing"},
+	{114, "NAEFS Products from joined NCEP, CMC global ensembles"},
+	{115, "Downscaled GFS from NAM eXtension"},
+	{116, "WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)"},
+	{117, "NEMS GFS Aerosol Component"},
+	{118, "URMA (UnRestricted Mesoscale Analysis)"},
+	{119, "WAM (Whole Atmosphere Model)"},
 	{120, "Ice Concentration Analysis"},
 	{121, "Western North Atlantic Regional Wave Model"},
 	{122, "Alaska Waters Regional Wave Model"},
 	{123, "North Atlantic Hurricane Wave Model"},
 	{124, "Eastern North Pacific Regional Wave Model"},
-        {125, "North Pacific Hurricane Wave Model"},
-        {126, "Sea Ice Forecast Model"},
-        {127, "Lake Ice Forecast Model"},
-        {128, "Global Ocean Forecast Model"},
-        {129, "Global Ocean Data Analysis System (GODAS)"},
-        {130, "Merge of fields from the RUC, Eta, and Spectral Model"},
-        {131, "Great Lakes Wave Model"},
+	{125, "North Pacific Hurricane Wave Model"},
+	{126, "Sea Ice Forecast Model"},
+	{127, "Lake Ice Forecast Model"},
+	{128, "Global Ocean Forecast Model"},
+	{129, "Global Ocean Data Analysis System (GODAS)"},
+	{130, "Merge of fields from the RUC, NAM, and Spectral Model"},
+	{131, "Great Lakes Wave Model"},
 	{140, "North American Regional Reanalysis (NARR)"},
 	{141, "Land Data Assimilation and Forecast System"},
 	{150, "NWS River Forecast System (NWSRFS)"},
@@ -338,20 +363,23 @@ GribTable models[] = {
 	{181, "River Forecast Center Quantitative Precipitation Forecast mosaic generated by NCEP"},
 	{182, "River Forecast Center Quantitative Precipitation estimate mosaic generated by NCEP"},
 	{183, "NDFD product generated by NCEP/HPC"},
+	{184, "Climatological Calibrated Precipitation Analysis - CCPA"},
 	{190, "National Convective Weather Diagnostic generated by NCEP/AWC"},
-        {191, "Current Icing Potential automated product genterated by NCEP/AWC"},
+	{191, "Current Icing Potential automated product generated by NCEP/AWC"},
 	{192, "Analysis product from NCEP/AWC"},
-        {193, "Forecast product from NCEP/AWC"},
-        {195, "Climate Data Assimilation System 2 (CDAS2)"},
-        {196, "Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs"},
-        {197, "Climate Data Assimilation System (CDAS)"},
-        {198, "Climate Data Assimilation System (CDAS) - used for regeneration runs"},
-        {200, "CPC Manual Forecast Product"},
-        {201, "CPC Automated Product"},
-        {210, "EPA Air Quality Forecast - Currently North East US domain"},
-        {211, "EPA Air Quality Forecast - Currently Eastern US domain"},
-        {215, "SPC Manual Forecast Product"},
-        {220, "NCEP/OPC automated product"}
+	{193, "Forecast product from NCEP/AWC"},
+	{195, "Climate Data Assimilation System 2 (CDAS2)"},
+	{196, "Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs"},
+	{197, "Climate Data Assimilation System (CDAS)"},
+	{198, "Climate Data Assimilation System (CDAS) - used for regeneration runs"},
+	{199, "Climate Forecast System Reanalysis (CFSR) -- Atmospheric model (GFS) coupled to a multi level ocean, land and seaice model (Currently GFS spectral model at T382, 64 levels coupled to 40 level MOM4 ocean model)"},
+	{200, "CPC Manual Forecast Product"},
+	{201, "CPC Automated Product"},
+	{210, "EPA Air Quality Forecast - Currently North East US domain"},
+	{211, "EPA Air Quality Forecast - Currently Eastern US domain"},
+	{215, "SPC Manual Forecast Product"},
+	{220, "NCEP/OPC automated product"},
+	{255, "Missing"}
 };
 
 int level_index[] = {1,2,3,4,5,6,7,8,9,20,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,
